var hierarchy =
[
    [ "MailMessage::Message", "../../MailMessage/html/class_mail_message_1_1_message.html", [
      [ "SmtpClient::Message", "class_smtp_client_1_1_message.html", null ]
    ] ],
    [ "MailMessage::Part", "../../MailMessage/html/class_mail_message_1_1_part.html", [
      [ "MailMessage::Attachment", "../../MailMessage/html/class_mail_message_1_1_attachment.html", [
        [ "SmtpClient::Attachment", "class_smtp_client_1_1_attachment.html", null ]
      ] ]
    ] ],
    [ "SmtpClient::SmtpClient", "class_smtp_client_1_1_smtp_client.html", null ],
    [ "SmtpClient::SmtpConnection", "class_smtp_client_1_1_smtp_connection.html", null ],
    [ "SmtpClient::SmtpResponseInfo", "struct_smtp_client_1_1_smtp_response_info.html", null ]
];